#
# spec file for package urh
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2017, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           urh
Version:        2.0.4
Release:        lp150.1.1
Summary:        Tool for investigating unknown wireless protocols
License:        Apache-2.0 AND GPL-2.0-only
Group:          Productivity/Hamradio/Other
URL:            https://github.com/jopohl/urh
Source:         https://github.com/jopohl/urh/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source99:       %{name}-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  limesuite-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-devel >= 3.4
BuildRequires:  python3-numpy
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-qt5
BuildRequires:  python3-setuptools
BuildRequires:  pkgconfig(libairspy)
BuildRequires:  pkgconfig(libhackrf)
BuildRequires:  pkgconfig(librtlsdr)
BuildRequires:  pkgconfig(uhd)
Requires:       hicolor-icon-theme
Requires:       python3-numpy
Requires:       python3-psutil
Requires:       python3-pyzmq
Requires:       python3-qt5
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun): hicolor-icon-theme
Requires(postun): update-desktop-files
Recommends:     inspectrum
Recommends:     rfcat
%if 0%{?suse_version} >= 1500
BuildRequires:  python3-PyAudio
%endif
%if 0%{?suse_version} >= 1500
Requires:       python3-PyAudio
%endif

%description
The Universal Radio Hacker is a software for investigating unknown wireless
protocols.

%prep
%setup -q

%build
python3 setup.py build \
    --with-airspy \
    --with-hackrf \
    --with-limesdr \
    --with-rtlsdr \
    --with-usrp

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
%fdupes %{buildroot}%{python3_sitearch}
install -Dpm 0644 data/icons/appicon.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/urh.svg
%suse_update_desktop_file -i -r urh "Network;HamRadio"

%files
%license LICENSE
%doc README.md
%{_bindir}/urh
%{_datadir}/icons/hicolor/scalable/apps/urh.svg
%{_datadir}/applications/urh.desktop
%{python3_sitearch}/urh
%{python3_sitearch}/urh-%{version}-py%{py3_ver}.egg-info

%changelog
* Mon May  7 2018 mardnh@gmx.de
- Update to version 2.0.4
  * Improve external program behaviour in Simulator
  * Improve simulator useability
  * Improve transcript for external programs
  * make endianness selectable in order column
  * UI improvements
  * add support for soundcards as new SDR device
  * Multi device support
  * add support for 24bit wav
* Mon Apr 23 2018 mardnh@gmx.de
- Update to version 2.0.2
  * Improve external program behaviour in Simulator
  * Improve simulator useability
  * Improve transcript for external programs
  * Make endianness selectable in order column
  * UI improvements
* Fri Mar 23 2018 mardnh@gmx.de
- Update to version 2.0.1
  * Bugfix release
* Wed Feb 28 2018 mardnh@gmx.de
- Update to version 2.0.0
  * Add Simulator mode
  * Performance and stability improvements:
  - improve accuracy when sending messages with short pauses
  - improve accuracy of protocol sniffer
  - allow setting lower frequencies for HackRF (#396)
  - consider latest changes of LimeSuite API (#397)
  - add timestamp to protocol sniffer output (#392)
  - improve performance of modulations
  - improve performance of filtering in analysis
  - improve performance when starting sending
  - improve send accuracy of HackRF
  - improve performance when filtering messages in Analysis
* Fri Jan 19 2018 mardnh@gmx.de
- Update to version 1.9.2
  * Add BCD (Binary Coded Decimal) as new display format
  * Make bit order configurable in analysis view table
  * Improved loading of protocol files
- Package svg version of the app-icon
* Tue Dec 19 2017 guillaume@opensuse.org
- Add more required runtime deps:
  * python3-pyzmq
  * python3-qt5
* Mon Dec 18 2017 mardnh@gmx.de
- Update to version 1.9.1
  * hotfix release that fixes an error with HackRF receiving
* Sun Dec 17 2017 mardnh@gmx.de
- Update to version 1.9.0
  * added native support for SDRplay
  * improved performance for continuous send mode
  * added collapsable comboboxes to device dialog
* Mon Dec  4 2017 mardnh@gmx.de
- Update to version 1.8.17
  * show warning at bottom if no project loaded
  * if no project is opened an new project is created, add
    currently opnened files to new project
  * add --version flag to command line script
* Thu Nov 30 2017 mardnh@gmx.de
- Update to version 1.8.16
  * This release fixes an issue on Windows where processes ended
    with an error.
  * The NetworkSDR can now be used in continuous send mode
* Mon Nov 27 2017 mardnh@gmx.de
- Update to version 1.8.15
  * This release fixes a problem mentioned in #366 and #368
    with GNU Radio backend on Windows.
* Sun Nov 26 2017 mardnh@gmx.de
- Update to version 1.8.14
  * This release fixes an overflow error (#364) when modulating
    very long messages in Generator.
  * The highlight of this release is an enhanced spectrum analyzer
    (#365) with increased performance and a waterfall plot to have
    a different, time based perspective on the spectrum.
* Sat Nov 18 2017 mardnh@gmx.de
- Update to version 1.8.13
* Thu Nov 16 2017 mardnh@gmx.de
- Update to version 1.8.12
  * added a CSV import wizard for generic support of USB oscilloscopes
* Mon Nov 13 2017 mardnh@gmx.de
- Update to version 1.8.11
  The following issues were fixed in this release:
  * crash when entering bits on empty position in Analysis/Generation
  * bandpass filter can now also work with negative frequencies
  * bandpass filter operations now run in a separate process and
    can be canceled with the ESC button
  * added a csv import to work with USB oscilloscopes
  * added a advanced modulation menu in Interpretation where a
    minimum message length for ASK can be configured
* Thu Nov  9 2017 mardnh@gmx.de
- Remove macros %%desktop_database_post and %%icon_theme_cache_post
  from %%post and %%postun section. These macros are not longer
  needed.
* Sun Nov  5 2017 jengelh@inai.de
- Update summary.
* Sun Oct 22 2017 mardnh@gmx.de
- Update to version 1.8.10
* Sun Oct 22 2017 mardnh@gmx.de
- Initial package, version 1.8.8
